@@ -14,9 +14,9 @@ specific language governing permissions and limitations
 under the License.
 """
 
-from gs_quant.target.common import *
+from gs_quant.common import *
 import datetime
-from typing import Mapping, Tuple, Union
+from typing import Mapping, Tuple, Union, Optional
 from enum import Enum
 from gs_quant.base import Base, EnumBase, InstrumentBase, camel_case_translate, get_enum_value
 
@@ -27,10 +27,7 @@ class MDAPIQueryField(EnumBase, Enum):
     bid = 'bid'
     mid = 'mid'
     expectedDataQuality = 'expectedDataQuality'
-    actualDataQuality = 'actualDataQuality'
-    
-    def __repr__(self):
-        return self.value
+    actualDataQuality = 'actualDataQuality'    
 
 
 class MDAPIDataQuery(Base):
